| Name                         | Version        | License                                                                                          |
|------------------------------|----------------|--------------------------------------------------------------------------------------------------|
| Babel                        | 2.15.0         | BSD License                                                                                      |
| Django                       | 5.2            | BSD License                                                                                      |
| Eel                          | 0.18.1         | MIT License                                                                                      |
| GitPython                    | 3.1.44         | BSD License                                                                                      |
| HyperPyYAML                  | 1.2.2          | Apache Software License                                                                          |
| ImageHash                    | 4.3.1          | 2-clause BSD License                                                                             |
| Jinja2                       | 3.1.4          | BSD License                                                                                      |
| MarkupSafe                   | 2.1.5          | BSD License                                                                                      |
| MouseInfo                    | 0.1.3          | GNU General Public License v3 or later (GPLv3+)                                                  |
| PyAudio                      | 0.2.14         | MIT License                                                                                      |
| PyAutoGUI                    | 0.9.54         | BSD License                                                                                      |
| PyDirectInput                | 1.0.4          | MIT License                                                                                      |
| PyGetWindow                  | 0.0.9          | BSD License                                                                                      |
| PyJWT                        | 2.10.1         | MIT License                                                                                      |
| PyMsgBox                     | 1.0.9          | GNU General Public License v3 or later (GPLv3+)                                                  |
| PyMuPDF                      | 1.25.5         | Dual Licensed - GNU AFFERO GPL 3.0 or Artifex Commercial License                                 |
| PyPDF2                       | 3.0.1          | BSD License                                                                                      |
| PyQt5                        | 5.15.10        | GPL v3                                                                                           |
| PyQt5-Qt5                    | 5.15.2         | LGPL v3                                                                                          |
| PyQt5-sip                    | 12.13.0        | SIP                                                                                              |
| PyRect                       | 0.2.0          | BSD License                                                                                      |
| PyScreeze                    | 0.1.30         | MIT License                                                                                      |
| PySocks                      | 1.7.1          | BSD                                                                                              |
| PyWavelets                   | 1.7.0          | MIT License                                                                                      |
| PyYAML                       | 6.0.1          | MIT License                                                                                      |
| Pygments                     | 2.18.0         | BSD License                                                                                      |
| Send2Trash                   | 1.8.3          | BSD License                                                                                      |
| SpeechRecognition            | 3.14.2         | BSD License                                                                                      |
| StrEnum                      | 0.4.15         | MIT License                                                                                      |
| accelerate                   | 1.6.0          | Apache Software License                                                                          |
| aiofiles                     | 24.1.0         | Apache Software License                                                                          |
| aiohappyeyeballs             | 2.6.1          | Python Software Foundation License                                                               |
| aiohttp                      | 3.11.18        | Apache Software License                                                                          |
| aiosignal                    | 1.3.2          | Apache Software License                                                                          |
| altgraph                     | 0.17.4         | MIT License                                                                                      |
| annotated-types              | 0.7.0          | MIT License                                                                                      |
| ansicon                      | 1.89.0         | Mozilla Public License 2.0 (MPL 2.0)                                                             |
| anyio                        | 4.4.0          | MIT License                                                                                      |
| argon2-cffi                  | 23.1.0         | MIT License                                                                                      |
| argon2-cffi-bindings         | 21.2.0         | MIT License                                                                                      |
| arrow                        | 1.3.0          | Apache Software License                                                                          |
| asgiref                      | 3.8.1          | BSD License                                                                                      |
| asttokens                    | 2.4.1          | Apache 2.0                                                                                       |
| async-lru                    | 2.0.4          | MIT License                                                                                      |
| attrs                        | 23.2.0         | MIT License                                                                                      |
| audioread                    | 3.0.1          | UNKNOWN                                                                                          |
| auto-py-to-exe               | 2.46.0         | MIT License                                                                                      |
| av                           | 14.3.0         | BSD License                                                                                      |
| backoff                      | 2.2.1          | MIT License                                                                                      |
| beautifulsoup4               | 4.12.3         | MIT License                                                                                      |
| bleach                       | 6.1.0          | Apache Software License                                                                          |
| blessed                      | 1.21.0         | MIT License                                                                                      |
| blis                         | 1.3.0          | BSD License                                                                                      |
| bottle                       | 0.13.2         | MIT License                                                                                      |
| bottle-websocket             | 0.2.9          | MIT License                                                                                      |
| build                        | 1.2.2.post1    | MIT License                                                                                      |
| cachetools                   | 5.5.2          | MIT License                                                                                      |
| catalogue                    | 2.0.10         | MIT License                                                                                      |
| certifi                      | 2024.2.2       | Mozilla Public License 2.0 (MPL 2.0)                                                             |
| cffi                         | 1.17.1         | MIT License                                                                                      |
| chardet                      | 5.2.0          | GNU Lesser General Public License v2 or later (LGPLv2+)                                          |
| charset-normalizer           | 3.3.2          | MIT License                                                                                      |
| click                        | 8.1.8          | BSD License                                                                                      |
| cloudpathlib                 | 0.21.0         | MIT License                                                                                      |
| colorama                     | 0.4.6          | BSD License                                                                                      |
| coloredlogs                  | 15.0.1         | MIT License                                                                                      |
| comm                         | 0.2.2          | BSD License                                                                                      |
| comtypes                     | 1.4.10         | MIT License                                                                                      |
| confection                   | 0.1.5          | MIT License                                                                                      |
| contourpy                    | 1.2.1          | BSD License                                                                                      |
| cryptography                 | 44.0.3         | Apache Software License; BSD License                                                             |
| cssselect                    | 1.3.0          | BSD License                                                                                      |
| ctranslate2                  | 4.6.0          | MIT License                                                                                      |
| curated-tokenizers           | 0.0.9          | MIT License                                                                                      |
| curated-transformers         | 0.1.1          | MIT                                                                                              |
| cycler                       | 0.12.1         | BSD License                                                                                      |
| cymem                        | 2.0.11         | MIT License                                                                                      |
| dacite                       | 1.8.1          | MIT License                                                                                      |
| datasets                     | 3.5.1          | Apache Software License                                                                          |
| debugpy                      | 1.8.2          | MIT License                                                                                      |
| decompyle3                   | 3.9.2          | GNU General Public License v3 (GPLv3)                                                            |
| decorator                    | 4.4.2          | BSD License                                                                                      |
| defusedxml                   | 0.7.1          | Python Software Foundation License                                                               |
| deprecation                  | 2.1.0          | Apache Software License                                                                          |
| dill                         | 0.3.8          | BSD License                                                                                      |
| distlib                      | 0.3.9          | Python Software Foundation License                                                               |
| distro                       | 1.9.0          | Apache Software License                                                                          |
| dnspython                    | 2.7.0          | ISC License (ISCL)                                                                               |
| docopt                       | 0.6.2          | MIT License                                                                                      |
| docutils                     | 0.21.2         | BSD License; GNU General Public License (GPL); Public Domain; Python Software Foundation License |
| dotenv                       | 0.9.9          | UNKNOWN                                                                                          |
| easyocr                      | 1.7.2          | Apache License 2.0                                                                               |
| editor                       | 1.6.6          | MIT License                                                                                      |
| en_core_web_sm               | 3.8.0          | MIT                                                                                              |
| en_core_web_trf              | 3.8.0          | MIT                                                                                              |
| executing                    | 2.2.0          | MIT License                                                                                      |
| fastapi                      | 0.115.12       | MIT License                                                                                      |
| faster-whisper               | 1.1.1          | MIT License                                                                                      |
| fastjsonschema               | 2.20.0         | BSD License                                                                                      |
| feedfinder2                  | 0.0.4          | MIT License                                                                                      |
| feedparser                   | 6.0.11         | BSD License                                                                                      |
| ffmpy                        | 0.5.0          | MIT License                                                                                      |
| ffpyplayer                   | 4.5.2          | GNU Lesser General Public License v3 (LGPLv3)                                                    |
| filelock                     | 3.18.0         | The Unlicense (Unlicense)                                                                        |
| flatbuffers                  | 25.2.10        | Apache Software License                                                                          |
| fonttools                    | 4.53.1         | MIT License                                                                                      |
| fqdn                         | 1.5.1          | Mozilla Public License 2.0 (MPL 2.0)                                                             |
| freeai-utils                 | 0.1.0          | UNKNOWN                                                                                          |
| frozenlist                   | 1.6.0          | Apache-2.0                                                                                       |
| fsspec                       | 2025.3.0       | BSD License                                                                                      |
| fundamentals                 | 2.7.2          | MIT License                                                                                      |
| future                       | 1.0.0          | MIT License                                                                                      |
| gTTS                         | 2.5.4          | MIT License                                                                                      |
| gevent                       | 24.11.1        | MIT License                                                                                      |
| gevent-websocket             | 0.10.1         | Copyright 2011-2017 Jeffrey Gelens <jeffrey@noppo.pro>                                           |
| gif_pygame                   | 1.1.2          | MIT License                                                                                      |
| gitdb                        | 4.0.12         | BSD License                                                                                      |
| google                       | 3.0.0          | BSD License                                                                                      |
| google-ai-generativelanguage | 0.6.15         | Apache Software License                                                                          |
| google-api-core              | 2.24.2         | Apache Software License                                                                          |
| google-api-python-client     | 2.167.0        | Apache Software License                                                                          |
| google-auth                  | 2.39.0         | Apache Software License                                                                          |
| google-auth-httplib2         | 0.2.0          | Apache Software License                                                                          |
| google-cloud-texttospeech    | 2.26.0         | Apache Software License                                                                          |
| google-cloud-vision          | 3.10.1         | Apache Software License                                                                          |
| google-generativeai          | 0.8.4          | Apache Software License                                                                          |
| googleapis-common-protos     | 1.70.0         | Apache Software License                                                                          |
| googlesearch-python          | 1.3.0          | MIT License                                                                                      |
| gotrue                       | 2.12.0         | MIT License                                                                                      |
| gradio                       | 5.28.0         | UNKNOWN                                                                                          |
| gradio_client                | 1.10.0         | Apache Software License                                                                          |
| graphviz                     | 0.20.3         | MIT License                                                                                      |
| greenlet                     | 3.1.1          | MIT License                                                                                      |
| groovy                       | 0.1.2          | MIT License                                                                                      |
| grpcio                       | 1.72.0rc1      | Apache Software License                                                                          |
| grpcio-status                | 1.71.0         | Apache Software License                                                                          |
| h11                          | 0.14.0         | MIT License                                                                                      |
| h2                           | 4.2.0          | MIT License                                                                                      |
| halo                         | 0.0.31         | MIT                                                                                              |
| haystack-ai                  | 2.13.1         | Apache Software License; Freely Distributable                                                    |
| haystack-experimental        | 0.9.0          | Apache Software License; Freely Distributable                                                    |
| hpack                        | 4.1.0          | MIT License                                                                                      |
| htmlmin                      | 0.1.12         | BSD License                                                                                      |
| httpcore                     | 1.0.5          | BSD License                                                                                      |
| httplib2                     | 0.22.0         | MIT License                                                                                      |
| httpx                        | 0.27.0         | BSD License                                                                                      |
| huggingface-hub              | 0.30.2         | Apache Software License                                                                          |
| humanfriendly                | 10.0           | MIT License                                                                                      |
| hyperframe                   | 6.1.0          | MIT License                                                                                      |
| icecream                     | 2.1.4          | MIT License                                                                                      |
| id                           | 1.5.0          | Apache Software License                                                                          |
| idna                         | 3.6            | BSD License                                                                                      |
| imageio                      | 2.34.0         | BSD License                                                                                      |
| imageio-ffmpeg               | 0.4.9          | BSD License                                                                                      |
| iniconfig                    | 2.1.0          | MIT License                                                                                      |
| inquirer                     | 3.4.0          | MIT License                                                                                      |
| ipykernel                    | 6.29.5         | BSD License                                                                                      |
| ipython                      | 8.26.0         | BSD License                                                                                      |
| ipywidgets                   | 8.1.5          | BSD License                                                                                      |
| isoduration                  | 20.11.0        | ISC License (ISCL)                                                                               |
| jaraco.classes               | 3.4.0          | MIT License                                                                                      |
| jaraco.context               | 6.0.1          | MIT License                                                                                      |
| jaraco.functools             | 4.1.0          | MIT License                                                                                      |
| jedi                         | 0.19.1         | MIT License                                                                                      |
| jieba3k                      | 0.35.1         | UNKNOWN                                                                                          |
| jinxed                       | 1.3.0          | Mozilla Public License 2.0 (MPL 2.0)                                                             |
| jiter                        | 0.9.0          | MIT License                                                                                      |
| joblib                       | 1.4.2          | BSD License                                                                                      |
| json5                        | 0.9.25         | Apache Software License                                                                          |
| jsonpointer                  | 3.0.0          | BSD License                                                                                      |
| jsonschema                   | 4.23.0         | MIT License                                                                                      |
| jsonschema-specifications    | 2023.12.1      | MIT License                                                                                      |
| jupyter-events               | 0.10.0         | BSD License                                                                                      |
| jupyter-lsp                  | 2.2.5          | BSD License                                                                                      |
| jupyter_client               | 8.6.2          | BSD License                                                                                      |
| jupyter_core                 | 5.7.2          | BSD License                                                                                      |
| jupyter_server               | 2.14.2         | BSD License                                                                                      |
| jupyter_server_terminals     | 0.5.3          | BSD License                                                                                      |
| jupyterlab                   | 4.2.4          | BSD License                                                                                      |
| jupyterlab_pygments          | 0.3.0          | BSD License                                                                                      |
| jupyterlab_server            | 2.27.3         | BSD License                                                                                      |
| jupyterlab_widgets           | 3.0.13         | BSD License                                                                                      |
| keyboard                     | 0.13.5         | MIT License                                                                                      |
| keyring                      | 25.6.0         | MIT License                                                                                      |
| kiwisolver                   | 1.4.5          | BSD License                                                                                      |
| lameenc                      | 1.8.1          | GNU Lesser General Public License v3 (LGPLv3)                                                    |
| langcodes                    | 3.5.0          | MIT License                                                                                      |
| langdetect                   | 1.0.9          | Apache Software License                                                                          |
| language_data                | 1.3.0          | MIT License                                                                                      |
| lazy_imports                 | 0.4.0          | Apache Software License                                                                          |
| lazy_loader                  | 0.4            | BSD License                                                                                      |
| librosa                      | 0.11.0         | ISC License (ISCL)                                                                               |
| lightgbm                     | 4.5.0          | MIT License                                                                                      |
| llvmlite                     | 0.43.0         | BSD                                                                                              |
| lockfile                     | 0.12.2         | MIT License                                                                                      |
| log-symbols                  | 0.0.14         | MIT                                                                                              |
| lxml                         | 5.3.2          | BSD License                                                                                      |
| lxml_html_clean              | 0.4.2          | BSD-3-Clause                                                                                     |
| marisa-trie                  | 1.2.1          | MIT License                                                                                      |
| markdown-it-py               | 3.0.0          | MIT License                                                                                      |
| matplotlib                   | 3.9.2          | Python Software Foundation License                                                               |
| matplotlib-inline            | 0.1.7          | BSD License                                                                                      |
| mdurl                        | 0.1.2          | MIT License                                                                                      |
| mistune                      | 3.0.2          | BSD License                                                                                      |
| more-itertools               | 10.7.0         | MIT License                                                                                      |
| mouse                        | 0.7.1          | MIT License                                                                                      |
| moviepy                      | 1.0.3          | MIT License                                                                                      |
| mpmath                       | 1.3.0          | BSD License                                                                                      |
| msgpack                      | 1.1.0          | Apache Software License                                                                          |
| mss                          | 10.0.0         | MIT License                                                                                      |
| multidict                    | 6.4.3          | Apache Software License                                                                          |
| multimethod                  | 1.12           | Apache Software License                                                                          |
| multiprocess                 | 0.70.16        | BSD License                                                                                      |
| murmurhash                   | 1.0.12         | MIT License                                                                                      |
| nbclient                     | 0.10.0         | BSD License                                                                                      |
| nbconvert                    | 7.16.4         | BSD License                                                                                      |
| nbformat                     | 5.10.4         | BSD License                                                                                      |
| neat-python                  | 0.92           | BSD License                                                                                      |
| nest-asyncio                 | 1.6.0          | BSD License                                                                                      |
| networkx                     | 3.3            | BSD License                                                                                      |
| newspaper3k                  | 0.2.8          | MIT                                                                                              |
| nh3                          | 0.2.21         | MIT                                                                                              |
| ninja                        | 1.11.1.4       | Apache Software License; BSD License                                                             |
| nltk                         | 3.9.1          | Apache Software License                                                                          |
| noisereduce                  | 3.0.3          | BSD License                                                                                      |
| notebook                     | 7.2.1          | BSD License                                                                                      |
| notebook_shim                | 0.2.4          | BSD License                                                                                      |
| npm                          | 0.1.1          | UNKNOWN                                                                                          |
| numba                        | 0.60.0         | BSD License                                                                                      |
| numpy                        | 2.0.2          | BSD License                                                                                      |
| oauthlib                     | 3.2.2          | BSD License                                                                                      |
| onnxruntime                  | 1.21.1         | MIT License                                                                                      |
| openai                       | 1.74.0         | Apache Software License                                                                          |
| openai-whisper               | 20240930       | MIT                                                                                              |
| opencv-contrib-python        | 4.10.0.84      | Apache Software License                                                                          |
| opencv-python                | 4.9.0.80       | Apache Software License                                                                          |
| opencv-python-headless       | 4.9.0.80       | Apache Software License                                                                          |
| openwakeword                 | 0.6.0          | Apache Software License                                                                          |
| optional-django              | 0.1.0          | UNKNOWN                                                                                          |
| orjson                       | 3.10.18        | Apache Software License; MIT License                                                             |
| outcome                      | 1.3.0.post0    | Apache Software License; MIT License                                                             |
| overrides                    | 7.7.0          | Apache License, Version 2.0                                                                      |
| packaging                    | 25.0           | Apache Software License; BSD License                                                             |
| pandas                       | 2.2.2          | BSD License                                                                                      |
| pandocfilters                | 1.5.1          | BSD License                                                                                      |
| parso                        | 0.8.4          | MIT License                                                                                      |
| patsy                        | 0.5.6          | BSD License                                                                                      |
| pdfminer.six                 | 20250327       | UNKNOWN                                                                                          |
| pdfplumber                   | 0.11.6         | MIT License                                                                                      |
| pefile                       | 2023.2.7       | MIT                                                                                              |
| phik                         | 0.12.4         | MIT License                                                                                      |
| pillow                       | 10.2.0         | Historical Permission Notice and Disclaimer (HPND)                                               |
| platformdirs                 | 4.3.8          | MIT License                                                                                      |
| playsound                    | 1.2.2          | MIT License                                                                                      |
| plotly                       | 5.24.0         | MIT License                                                                                      |
| pluggy                       | 1.5.0          | MIT License                                                                                      |
| pooch                        | 1.8.2          | BSD License                                                                                      |
| postgrest                    | 1.0.1          | MIT License                                                                                      |
| posthog                      | 4.0.1          | MIT License                                                                                      |
| preshed                      | 3.0.9          | MIT License                                                                                      |
| proglog                      | 0.1.10         | MIT                                                                                              |
| prometheus_client            | 0.20.0         | Apache Software License                                                                          |
| prompt_toolkit               | 3.0.47         | BSD License                                                                                      |
| propcache                    | 0.3.1          | Apache Software License                                                                          |
| proto-plus                   | 1.26.1         | Apache Software License                                                                          |
| protobuf                     | 5.29.4         | 3-Clause BSD License                                                                             |
| psutil                       | 5.9.8          | BSD License                                                                                      |
| pure-eval                    | 0.2.2          | MIT License                                                                                      |
| pvporcupine                  | 1.9.5          | Apache Software License                                                                          |
| pyarrow                      | 20.0.0         | Apache Software License                                                                          |
| pyasn1                       | 0.6.1          | BSD License                                                                                      |
| pyasn1_modules               | 0.4.2          | BSD License                                                                                      |
| pyclipper                    | 1.3.0.post6    | MIT License                                                                                      |
| pycparser                    | 2.21           | BSD License                                                                                      |
| pydantic                     | 2.8.2          | MIT License                                                                                      |
| pydantic_core                | 2.20.1         | MIT License                                                                                      |
| pydub                        | 0.25.1         | MIT License                                                                                      |
| pygame                       | 2.6.1          | GNU Library or Lesser General Public License (LGPL)                                              |
| pygame-ce                    | 2.5.1          | GNU Library or Lesser General Public License (LGPL)                                              |
| pyinstaller                  | 6.13.0         | GNU General Public License v2 (GPLv2)                                                            |
| pyinstaller-hooks-contrib    | 2025.3         | Apache Software License; GNU General Public License v2 (GPLv2)                                   |
| pymediainfo                  | 6.1.0          | MIT License                                                                                      |
| pyparsing                    | 3.1.2          | MIT License                                                                                      |
| pypdf                        | 5.4.0          | BSD License                                                                                      |
| pypdfium2                    | 4.30.1         | BSD-3-Clause, Apache-2.0, PdfiumThirdParty                                                       |
| pyperclip                    | 1.8.2          | BSD License                                                                                      |
| pypiwin32                    | 223            | UNKNOWN                                                                                          |
| pyproject-api                | 1.9.0          | MIT License                                                                                      |
| pyproject_hooks              | 1.2.0          | MIT License                                                                                      |
| pyreadline3                  | 3.5.4          | BSD License                                                                                      |
| pytesseract                  | 0.3.13         | Apache Software License                                                                          |
| pytest                       | 8.3.5          | MIT License                                                                                      |
| pytest-mock                  | 3.14.0         | MIT License                                                                                      |
| pytextrank                   | 3.3.0          | MIT License                                                                                      |
| python-bidi                  | 0.6.6          | GNU Library or Lesser General Public License (LGPL)                                              |
| python-daemon                | 3.1.2          | Apache Software License                                                                          |
| python-dateutil              | 2.9.0.post0    | Apache Software License; BSD License                                                             |
| python-docx                  | 1.1.2          | MIT License                                                                                      |
| python-dotenv                | 1.0.1          | BSD License                                                                                      |
| python-json-logger           | 2.0.7          | BSD License                                                                                      |
| python-multipart             | 0.0.20         | Apache Software License                                                                          |
| pyttsx3                      | 2.98           | Mozilla Public License 2.0 (MPL 2.0)                                                             |
| pytweening                   | 1.2.0          | MIT License                                                                                      |
| pytz                         | 2024.1         | MIT License                                                                                      |
| pyuseragents                 | 1.0.5          | MIT License                                                                                      |
| pywin32                      | 306            | Python Software Foundation License                                                               |
| pywin32-ctypes               | 0.2.2          | BSD-3-Clause                                                                                     |
| pywinpty                     | 2.0.13         | MIT                                                                                              |
| pyxel                        | 2.3.16         | MIT License                                                                                      |
| pyzmq                        | 26.0.3         | BSD License                                                                                      |
| readability-lxml             | 0.8.4.1        | Apache License 2.0                                                                               |
| readchar                     | 4.2.1          | MIT License                                                                                      |
| readme_renderer              | 44.0           | Apache Software License                                                                          |
| realtime                     | 2.4.3          | MIT License                                                                                      |
| referencing                  | 0.35.1         | MIT License                                                                                      |
| regex                        | 2024.11.6      | Apache Software License                                                                          |
| requests                     | 2.32.3         | Apache Software License                                                                          |
| requests-file                | 2.1.0          | Apache Software License                                                                          |
| requests-oauthlib            | 2.0.0          | BSD License                                                                                      |
| requests-toolbelt            | 1.0.0          | Apache Software License                                                                          |
| rfc3339-validator            | 0.1.4          | MIT License                                                                                      |
| rfc3986                      | 2.0.0          | Apache Software License                                                                          |
| rfc3986-validator            | 0.1.1          | MIT License                                                                                      |
| rich                         | 14.0.0         | MIT License                                                                                      |
| rpds-py                      | 0.19.0         | MIT License                                                                                      |
| rsa                          | 4.9            | Apache Software License                                                                          |
| ruamel.yaml                  | 0.18.10        | MIT License                                                                                      |
| ruamel.yaml.clib             | 0.2.12         | MIT License                                                                                      |
| ruff                         | 0.11.7         | MIT License                                                                                      |
| runs                         | 1.2.2          | MIT License                                                                                      |
| safehttpx                    | 0.1.6          | MIT License                                                                                      |
| safetensors                  | 0.5.3          | Apache Software License                                                                          |
| scikit-image                 | 0.25.2         | BSD License                                                                                      |
| scikit-learn                 | 1.5.1          | BSD License                                                                                      |
| scipy                        | 1.15.2         | BSD License                                                                                      |
| seaborn                      | 0.13.2         | BSD License                                                                                      |
| semantic-version             | 2.10.0         | BSD License                                                                                      |
| sentencepiece                | 0.2.0          | Apache Software License                                                                          |
| sgmllib3k                    | 1.0.0          | BSD License                                                                                      |
| shapely                      | 2.1.0          | BSD License                                                                                      |
| shellingham                  | 1.5.4          | ISC License (ISCL)                                                                               |
| six                          | 1.16.0         | MIT License                                                                                      |
| smart-open                   | 7.1.0          | MIT License                                                                                      |
| smmap                        | 5.0.2          | BSD License                                                                                      |
| sniffio                      | 1.3.1          | Apache Software License; MIT License                                                             |
| sortedcontainers             | 2.4.0          | Apache Software License                                                                          |
| sounddevice                  | 0.5.1          | MIT License                                                                                      |
| soundfile                    | 0.13.1         | BSD License                                                                                      |
| soupsieve                    | 2.5            | MIT License                                                                                      |
| soxr                         | 0.5.0.post1    | GNU Lesser General Public License v2 or later (LGPLv2+)                                          |
| spacy                        | 3.8.5          | MIT License                                                                                      |
| spacy-curated-transformers   | 0.3.0          | MIT                                                                                              |
| spacy-legacy                 | 3.0.12         | MIT License                                                                                      |
| spacy-loggers                | 1.0.5          | MIT                                                                                              |
| spark-parser                 | 1.8.9          | MIT                                                                                              |
| spinners                     | 0.0.24         | MIT                                                                                              |
| sqlparse                     | 0.5.3          | BSD License                                                                                      |
| srsly                        | 2.5.1          | MIT License                                                                                      |
| srt                          | 3.5.3          | MIT License                                                                                      |
| stack-data                   | 0.6.3          | MIT License                                                                                      |
| starlette                    | 0.46.2         | BSD License                                                                                      |
| statsmodels                  | 0.14.2         | BSD License                                                                                      |
| storage3                     | 0.11.3         | MIT License                                                                                      |
| supabase                     | 2.15.1         | MIT License                                                                                      |
| supafunc                     | 0.9.4          | MIT License                                                                                      |
| sympy                        | 1.13.1         | BSD License                                                                                      |
| tenacity                     | 9.0.0          | Apache Software License                                                                          |
| termcolor                    | 3.1.0          | UNKNOWN                                                                                          |
| terminado                    | 0.18.1         | BSD License                                                                                      |
| thinc                        | 8.3.6          | MIT License                                                                                      |
| threadpoolctl                | 3.5.0          | BSD License                                                                                      |
| tifffile                     | 2025.3.30      | BSD-3-Clause                                                                                     |
| tiktoken                     | 0.9.0          | MIT License                                                                                      |
|                              |                |                                                                                                  |
|                              |                | Copyright (c) 2022 OpenAI, Shantanu Jain                                                         |
|                              |                |                                                                                                  |
|                              |                | Permission is hereby granted, free of charge, to any person obtaining a copy                     |
|                              |                | of this software and associated documentation files (the "Software"), to deal                    |
|                              |                | in the Software without restriction, including without limitation the rights                     |
|                              |                | to use, copy, modify, merge, publish, distribute, sublicense, and/or sell                        |
|                              |                | copies of the Software, and to permit persons to whom the Software is                            |
|                              |                | furnished to do so, subject to the following conditions:                                         |
|                              |                |                                                                                                  |
|                              |                | The above copyright notice and this permission notice shall be included in all                   |
|                              |                | copies or substantial portions of the Software.                                                  |
|                              |                |                                                                                                  |
|                              |                | THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR                       |
|                              |                | IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,                         |
|                              |                | FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE                      |
|                              |                | AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER                           |
|                              |                | LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,                    |
|                              |                | OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE                    |
|                              |                | SOFTWARE.                                                                                        |
|                              |                |                                                                                                  |
| tinycss2                     | 1.3.0          | BSD License                                                                                      |
| tinysegmenter                | 0.3            | BSD License                                                                                      |
| tkVideo                      | 0.1            | MIT License                                                                                      |
| tldextract                   | 5.3.0          | BSD License                                                                                      |
| tokenizers                   | 0.21.1         | Apache Software License                                                                          |
| tomlkit                      | 0.13.2         | MIT License                                                                                      |
| torch                        | 2.6.0+cu118    | BSD License                                                                                      |
| torchaudio                   | 2.6.0+cu118    | BSD License                                                                                      |
| torchvision                  | 0.21.0         | BSD                                                                                              |
| tornado                      | 6.4.1          | Apache Software License                                                                          |
| tox                          | 4.25.0         | MIT License                                                                                      |
| tqdm                         | 4.67.1         | MIT License; Mozilla Public License 2.0 (MPL 2.0)                                                |
| traitlets                    | 5.14.3         | BSD License                                                                                      |
| transformers                 | 4.51.3         | Apache Software License                                                                          |
| trio                         | 0.25.0         | Apache Software License; MIT License                                                             |
| trio-websocket               | 0.11.1         | MIT License                                                                                      |
| twine                        | 6.1.0          | Apache Software License                                                                          |
| typeguard                    | 4.3.0          | MIT License                                                                                      |
| typer                        | 0.15.2         | MIT License                                                                                      |
| types-python-dateutil        | 2.9.0.20240316 | Apache Software License                                                                          |
| typing_extensions            | 4.13.2         | UNKNOWN                                                                                          |
| tzdata                       | 2024.1         | Apache Software License                                                                          |
| uncompyle6                   | 3.9.2          | MIT License                                                                                      |
| uri-template                 | 1.3.0          | MIT License                                                                                      |
| uritemplate                  | 4.1.1          | Apache Software License; BSD License                                                             |
| urllib3                      | 2.2.1          | MIT License                                                                                      |
| uvicorn                      | 0.34.2         | BSD License                                                                                      |
| virtualenv                   | 20.31.2        | MIT License                                                                                      |
| visions                      | 0.7.6          | BSD License                                                                                      |
| vosk                         | 0.3.45         | Apache Software License                                                                          |
| wasabi                       | 1.1.3          | MIT                                                                                              |
| weasel                       | 0.4.1          | MIT License                                                                                      |
| webcolors                    | 24.6.0         | BSD License                                                                                      |
| webencodings                 | 0.5.1          | BSD License                                                                                      |
| webrtcvad-wheels             | 2.0.14         | MIT License                                                                                      |
| websocket-client             | 1.8.0          | Apache Software License                                                                          |
| websockets                   | 15.0.1         | BSD License                                                                                      |
| widgetsnbextension           | 4.0.13         | BSD License                                                                                      |
| wordcloud                    | 1.9.3          | MIT License                                                                                      |
| wrapt                        | 1.17.2         | BSD License                                                                                      |
| wsproto                      | 1.2.0          | MIT License                                                                                      |
| xdis                         | 6.1.3          | MIT License                                                                                      |
| xgboost                      | 2.1.1          | Apache Software License                                                                          |
| xmod                         | 1.8.1          | MIT License                                                                                      |
| xxhash                       | 3.5.0          | BSD License                                                                                      |
| yarl                         | 1.20.0         | Apache Software License                                                                          |
| ydata-profiling              | 4.9.0          | MIT License                                                                                      |
| zope.event                   | 5.0            | Zope Public License                                                                              |
| zope.interface               | 7.2            | Zope Public License                                                                              |
